==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseToolbarDirectiveDescriptionMetadata } from "./WebBaseToolbarDirectiveDescriptionMetadata";
import { WebBaseToolbarColumnActionsDirectiveDescription } from "./WebBaseToolbarColumnActionsDirectiveDescription";
/**
 * @hidden
 */
export let WebBaseToolbarColumnActionsDirectiveDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebBaseToolbarColumnActionsDirectiveDescriptionMetadata extends Base {
        static b(a) {
            if (WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a == null) {
                WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.c(WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a);
            }
            if (a.k(WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseToolbarDirectiveDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:BaseToolbarColumnActionsDirective");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__skipSuffix", "Boolean");
            a.item("Name", "String");
        }
        static d(a) {
            WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.b(a);
            a.ac("WebBaseToolbarColumnActionsDirective", () => new WebBaseToolbarColumnActionsDirectiveDescription());
            a.ab("WebBaseToolbarColumnActionsDirective", WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a);
        }
    }
    WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.$t = /*@__PURE__*/ markType(WebBaseToolbarColumnActionsDirectiveDescriptionMetadata, 'WebBaseToolbarColumnActionsDirectiveDescriptionMetadata');
    WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a = null;
    return WebBaseToolbarColumnActionsDirectiveDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseToolbarDirectiveDescriptionMetadata } from "./WebBaseToolbarDirectiveDescriptionMetadata";
import { WebBaseToolbarColumnActionsDirectiveDescription } from "./WebBaseToolbarColumnActionsDirectiveDescription";
/**
 * @hidden
 */
export let WebBaseToolbarColumnActionsDirectiveDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebBaseToolbarColumnActionsDirectiveDescriptionMetadata extends Base {
        static b(a) {
            if (WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a == null) {
                WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.c(WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a);
            }
            if (a.k(WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseToolbarDirectiveDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:BaseToolbarColumnActionsDirective");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__skipSuffix", "Boolean");
            a.item("Name", "String");
        }
        static d(a) {
            WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.b(a);
            a.ae("WebBaseToolbarColumnActionsDirective", () => new WebBaseToolbarColumnActionsDirectiveDescription());
            a.ad("WebBaseToolbarColumnActionsDirective", WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a);
        }
    }
    WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.$t = /*@__PURE__*/ markType(WebBaseToolbarColumnActionsDirectiveDescriptionMetadata, 'WebBaseToolbarColumnActionsDirectiveDescriptionMetadata');
    WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a = null;
    return WebBaseToolbarColumnActionsDirectiveDescriptionMetadata;
})();
